package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````Z`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)`````````!RTR6(-K)+
MVS:R2]LVLDO;6:U!VSVR2]NUKD7;-+)+VUFM3]LTLDO;5*U8VS*R2]M-KD?;
M-+)+VS:R2MMFLDO;R9)/VS6R2]L`E$';-+)+VXZT3=LWLDO;4FEC:#:R2]L`
M`````````%!%``!,`00`:B#620``````````X``/`0L!!@``,````*``````
M``!L.0```!````!``````$```!`````0```$``````````0``````````.``
M```0``#3BP$``P``````$```$``````0```0````````$```````````````
M_)T``&0`````P```T!$``````````````````````````````````#!!```<
M``````````````````````````````````````````````````````````!`
M```H`0``````````````````````````````````+G1E>'0```"L*@```!``
M```P````$```````````````````(```8"YR9&%T80``[&,```!`````<```
M`$```````````````````$```$`N9&%T80```$0'````L````!````"P````
M``````````````!```#`+G)S<F,```#0$0```,`````@````P```````````
M````````0```P```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`&A`L$``:'XX0`!H)+!``.AD*```4.A8*```@\00PS/`PU6+[('L"`0``%-6
M5VAHL$``Z*@!``")1?R-A?C[___'!"0`!```,]M04_\5%$!``(7`#X5,`0``
M_S40L$``BW4(5O\5B$!``%E9A<!6=!-H6+!``.CS`0``68O&6>E7`0``Z)XH
M``#_-12P0`"+/9!`0`")1?C_=0S_UX/$#(OP._,/A!\!```X'G4%OE2P0``Y
M7?QT$U;_=?SH8"@``%F%P%D/A,L```!6Z%8H``"*5##_68L-$+!``#H1=0I(
MB!P&BE0&_^OLBU7X_W4(C400`3T`!```#XW-````45:-A?C[__]H3+!``%#_
M%:A`0`#H82<``%#H;2<``(LPZ%0G``!0Z%HG``"#Q!Q0C87X^___4.@^)P``
M4.A*)P``6?\P_U90@\0,A<!U2.@F)P``4.@L)P``9HM`!EEF)0#P9CT`@'4N
MZ`PG``!0Z!@G``"+,%F-A?C[__]J`5#H]28``%#H`2<``%G_,/\6@\0,A<!T
M$/\U%+!``%/_UUE9Z?K^__^-A?C[__]0:%BP0`#HMP```(V%^/O__U#_%41`
M0`"#Q`SK$O]U"&A8L$``Z)@```"+10A965]>6\G#58OLC44(4/]U".@$````
M65E=PU6+[%%35HMU"%>%]G1FBQV$0$``_].#.`!T68H.B\:$R70+@/D]=`:*
M2`%`Z_$KQHE%_/_3BS"+/H7_=#?_=?S_=0A7_Q5`0$``@\0,A<!U"8M%_(`\
M!SUT!8/&!.O8_],K,(M%#,'^`HDPBT7\C40'`>L",\!?7EO)PU6+[%%1BT4,
M@#@]=0/_10Q35E?_=0SHGB8``(M="(E%^(U%_%!3Z%K___^+-81`0`"+^(/$
M#(7_=")7Z'DF```[1?A9#X++````BTT,B@&(!T=!A,!U]ND\`0``_]:+`#/_
M,\DY"'0&@\`$1^OV.0T@MT``=$#HD"4``%#HHB4``(L868T$O0@```!0_];_
M,.AV)0``4.B()0``6?\P_U,$@\0,B]C_UHD8_]:#.`!U5>FQ````QP4@MT``
M`0```.A&)0``4.A8)0``BQA9C02]"````%#H,"4``%#H0B4``%G_,/\3B]A9
MA=M9='F+Q\'@`E#_UO\P4_\5@$!``(/$#/_6B1C_UHL`BUT(@V2X!`")??R*
M`XO[A,!T"CP]=`:*1P%'Z_+HWR0``%#H\20``(L0BT7X*_M9B54(C40'`E#H
MQ"0``%#HUB0``%G_,(M%"/\068OX6?_6BP"+3?R%_XD\B'4%@\C_ZR[_UHL`
MBTW\BP2(B@M#A,F("'0(@/D]=`-`Z^^+50S&`#U`B@J("$!"A,EU]C/`7UY;
MR<.+1"0$5HOPB\B*`(3`=!>+%1"P0`"*$CK"=0.-<0&*00%!A,!U\8O&7L-6
MBW0D"(7V=&^`/@!T:E;HW"0``(U$,/]9BPT0L$``.\9V%HH1.!!U!4@[QG?W
M.\9V"3@0=`-(Z_4[QG4)B@`Z`70U4>LW2#O&=@:*$#H1=/4KQHU(`H'Y``0`
M`'8$,\!>PT!05KX8LT``5O\5?$!``(/$#(O&7L-H5+!``/\51$!``%E>PU6+
M[(/L)%-65VH(6;X\L4``C7W<:"RQ0`#SI6:EZ`D!``#'!"0@L4``Z/T```"[
M:+!``%/H\@```+X4L4``5NCG````OPBQ0`!7Z-P```!H_+!``.C2````:%BP
M0`#HR````&CPL$``Z+X```!HY+!``.BT````:-"P0`#HHOS__X/$)(7`=`E0
M5^@B_?__65EHO+!``.B(_/__A<!9=`U0:+"P0`#H!OW__UE9:*"P0`#H;/S_
M_X7`670+4%/H[OS__UE9ZTYHC+!``.A2_/__A<!9=`105NOD:(2P0`#HAB,`
M`+]XL$``C5P%Z%?H=R,``%!74_\5>$!``(/$%(7`=1)7Z&$C```#PU!6Z)_\
M__^#Q`QH=+!``&@LL4``Z(W\__]965]>6\G#58OL48U%_%#_=0CH^_O__UF%
MP%ET'O\5A$!``(L`BTW\C0R(BU$$C4$$A=*)$734B\CK\,G#H1BP0`"#^/]U
M)6@4L4``Z*[[__^%P%ET#XH`A,!T"3PP=`5J`5CK`C/`HQBP0`##58OL@^P@
MN)2Q0`!7B_A0B47@QT7DC+%``,=%Z'RQ0`#'1>QTL4``QT7P8+%``,=%]"2W
M0`")??CHG"(``(7`60^&Q````(U%X%-6B47\5^@^^___B_!9A?8/A(,```!6
MZ'0B``"%P%ET>/]U"%;_%8A`0`!9A<!9=7/HK"$``%#HOB$``/\U%+!``(LX
MZ$<B``!6B]CH/R(``/]U"`/8Z#4B``"#Q!"-1`,"4.AZ(0``4.B,(0``6?\P
M_Q=6B_C_-12P0`#_=0AH3+!``%?_%:A`0`!7_W7XZ$/[__^#Q"3K"_]U"%?H
M-?O__UE9@T7\!(M%_(LX5XE]^.C:(0``A<!9#X=&____7EM?R<-5B^RXX(``
M`.C)(0``@V7\`%:X)+=``&AHL$``QT78/+)``,=%W""P0`#'1>!4L$``B47D
MQT7`L+!``,=%Q#2R0`#'1<@LLD``QT7,)+)``,=%T""R0`")1=3'1>@8LD``
MQT7L#+)``(E%\.@5^O__B_!9A?9T'U;H3R$``(7`67045NAK_O__5O\51$!`
M`%E9Z=,#``!3O@`$``!7B77XZ'D@``!0Z(L@``"+.%E6Z&H@``!0Z'P@``!9
M_S#_%UE9C4WX45#_%0!`0`#H\_?__XO8A=N)7?AU/8U]Z(LW5NCG(```A<!9
M=B!6Z)7Y__^%P%ET"U#_%41`0`!9B47XBUWX@\<$A=MTTX7;=0G'1?@$LD``
MZT.`.P"+\W0\OP<!``"A9$!``(,X`7X/#[X&5U#_%6A`0`!96>L1BPUL0$``
M#[X&BPEFBP1!(\>%P'4#Q@9?1H`^`'7)C7W`BS=6Z&<@``"%P%EV+%;H%?G_
M_XOP687V=!96Z`89``"%P%ET"U;_%41`0`!9B47\@\<$@WW\`'3'@WW\`(LU
MJ$!``'5Y:/RQ0`#HV?C__XO8687;=&CH9A\``%#H>!\``(LX4^@&(```68/`
M!EE0Z$T?``!0Z%\?``!9_S#_%XOX4VCTL4``5__65^B6&```@\08A<!T!8E]
M_.LBZ"`?``!0Z#(?``"+&%E7Z!$?``!0Z",?``!9_S#_4PA968-]_`!U+XU=
MV(L[5^B@'P``A<!9=A]7Z$P8``"%P%ET"U?_%41`0`!9B47\@\,$@WW\`'34
M_W7XZ'0?``#_=?R+^.AJ'P``N^RQ0``#^%/H71\``&@DMT```_CH41\``(V\
M!P`$``#HEQX``%#HJ1X``(L0@\04B57T5^B#'@``4.B5'@``6?\PBT7T_Q#_
M=?B+^%/_-1"P0`#_=?QHX+%``%?_UE?_%7!`0`!H=+%``.BT]___BUT(@\0H
MA<!T&5#_%41`0`!0_S/HW?7__X/$#(E%"(7`=06+`XE%".C%^___A<`/A4H"
M``#H$QX``%#H'QX``(L8QP0D`(```/]U".C\'0``4.@('@``6?\P_U,\@\0,
MB44(A<`/A!0"``#HW1T``%#HZ1T``(L866H":N[_=0CHR!T``%#HU!T``%G_
M,/]3,.BW'0``4.C#'0``BQB#Q!2-A2!___]J!E#_=0CHFQT``%#HIQT``%G_
M,/]31(/$$("]('___P`/A<T```"`O2%___]##X7`````@+TB?___00^%LP``
M`("](W___T,/A:8```"`O21___](#X69````@+TE?___10^%C````.@Y'0``
M4.A%'0``BQA9:@)JQO]U".@D'0``4.@P'0``6?\P_U,PZ!,=``!0Z!\=``"+
M&(/$%(V%('___VHI4/]U".CW'```4.@#'0``6?\P_U-$C84@?___:"2W0`!0
M_S40L$``5VC0L4``5__6@\0H5VAHL$``Z+?V__]7Z)'Z__^#Q`R+QU];7LG#
MC84@____4.B=`0``Z*$<``!0Z*T<``!968L8C84@?___:`"```!0_W4(Z(,<
M``!0Z(\<``!9_S#_4T2#Q!"%P'XD4(V%('___U"-A2#___]0Z(4!``#H5QP`
M`%#H8QP``(/$$.NSZ$<<``!0Z%,<``"+&%G_=0CH-AP``%#H0AP``%G_,/]3
M$(V%(/___U"-1:Q0Z"(4``"-18"#Q!`SVXE%"`^V1!VL4&C(L4``_W4(_]:#
M10@"@\0,0X/[%'SCC46`:"2W0`"`9:@`4/\U$+!``%=HT+%``%?_UH/$&.D!
M____@V4(`%?H<AP``,<$)'2P0`!H%+%``(E%].BE]?__65EH)+=``.BD&P``
M4.B\&P``BQCHEQL``%#HKQL``/\P_U-H@\0,4/\U$+!``%=HN+%``%?_UE?_
M%7!`0`"#Q!R#^/\/A9G^____%71`0`"#.!$/A8K^__^+1?1H)+=``(`D.`#_
M10C_=0CH0!L``%#H6!L``(L8Z#,;``!0Z$L;``#_,/]3:(/$#%#_-1"P0`!7
M:*2Q0`!7_]97_Q5P0$``@\0@ZYJ+1"0$,\G'``$C16?'0`2)J\WOQT`(_MRZ
MF,=`#'94,A#'0!#PX=+#B4@4B4@8B4A<PU6+[%.+71!6BW4(5XM.%(T$V3O!
M<P/_1AB)1A2+P\'H'0%&&(M&7(7`=#1J0%\K^#O[?@*+^XM&7%?_=0R-1`8<
M4.AX&P```7T,`7Y<@\0,*]^#?EQ`=4M6Z$H```!9@_M`?"R+^\'O!HO']]C!
MX`8#V&I`C48<_W4,4.@_&P``@T4,0%;H'@```(/$$$]UXE.-1AS_=0Q0Z"(;
M``"#Q`R)7EQ?7EM=PU6+[('L5`$``(M%"%-65XU0'(VUK/[__\=%"!````"+
M"H/"!(OYB]F!YP``_P#!ZQ`+^XO9@>,`_P``P>$0"]G![PC!XP@+^XD^@\8$
M_TT(=<UJ0(V5M/[__UZ+2BPS2A@S2O@S"H/"!(OY`\G![Q\+^4Z)>C1UXXMX
M!(M0"(MP#(L(B]\CU_?3(]Z+\0O:B]'!ZAO!Y@4+UHMP$`/S`]:+M:S^__^-
ME#*9>8):B_?!YA[![P(+]XOY]]<C>`B)=>PC\8O:"_Z+\L'K&\'F!0O>B[6P
M_O__`_<#WHMP#(V\,YEY@EJ+\8O9B7WXP>8>P>L""_.+VO?3(UWLB77\(_(+
MWHNUM/[__XE="(O?P>L;P><%"]^+?0@#]XOZP><>P>H"`]Z+<`@+^HM5^(VT
M,YEY@EJ+7?CWTB-5_"/?B7WTB_X+TXO>P>\;P>,%"_N+G;C^__\#V@/[BU7L
MC9P7F7F"6HM]^(O7B5T(P>(>P>\""]>+_O?7(WWTB57X(]8+^HO3P>H;P>,%
M"].+G;S^__\#WXM]_`/3C90ZF7F"6HO^P><>P>X""_Z+=0CWUB-U^(E]\"-]
M"(O:P>,%"_>+^L'O&PO[BYW`_O__`]Z+=?0#^XV<-YEY@EJ+?0B+]XE=_,'F
M'L'O`@OWB_KWUR-]\(EU""/R"_Z+\\'N&\'C!0OSBYW$_O__`]^+??@#\XVT
M/IEY@EJ+^L'G'L'J`@OZBU7\]](C50B)?>PC??R+WL'C!0O7B_[![QL+^XN=
MR/[__P/:BU7P`_N-G!>9>8):BWW\B]>)7?C!XA[![P(+UXO^]]<C?>R)5?PC
MU@OZB]/!ZAO!XP4+TXN=S/[__P/?BWT(`].+7?B-E#J9>8):B_[!YQ[![@(+
M_HMU^/?6(W7\(]^)??2+^@OSB]K![QO!XP4+^XN=T/[__P/>BW7L`_N-G#>9
M>8):BWWXB_>)70C!YA[![P(+]XOZ]]<C??2)=?@C\@O^B_/![AO!XP4+\XN=
MU/[__P/?BWW\`_.-M#Z9>8):B_K!YQ[!Z@(+^HM5"/?2(U7XB7WP(WT(B][!
MXP4+UXO^P>\;"_N+G=C^__\#VHM5]`/[C9P7F7F"6HM]"(O7B5W\P>(>P>\"
M"]>+_O?7(WWPB54((]8+^HO3P>H;P>,%"].+G=S^__\#WXM]^`/3C90ZF7F"
M6HO^P><>P>X""_Z+=?SWUB-U"(E]["-]_(O:P>,%"_>+^L'O&PO[BYW@_O__
M`]Z+=?`#^XV<-YEY@EJ+??R+]XE=^,'F'L'O`@OWB_KWUR-][(EU_"/R"_Z+
M\\'N&\'C!0OSBYWD_O__`]^+?0@#\XM=^(VT/IEY@EJ+^L'G'L'J`@OZBU7X
M]](C5?R)??0CWXO^"].+WL'O&\'C!0O[BYWH_O__`]J+5>P#^XV<%YEY@EJ+
M??B+UXE=",'B'L'O`@O7B_[WUR-]](E5^"/6"_J+T\'J&\'C!0O3BYWL_O__
M`]^+??P#TXV4.IEY@EJ+_L'G'L'N`@O^BW4(]]8C=?B)??`C?0B+VL'C!0OW
MB_K![QL+^XN=\/[__P/>BW7T`_N-G#>9>8):BWT(B_>)7?S!YA[![P(+]XOZ
M]]<C??")=0@C\@O^B_/![AO!XP4+\XN=]/[__P/?BWWX`_.-M#Z9>8):B_K!
MYQ[!Z@(+^HM5_/?2(U4(B7WL(WW\"]>+_L'O&XO>P>,%"_N+G?C^__\#VHM5
M\`/[C9P7F7F"6HM]_(O7B5WXP>(>P>\""]>+^\'O&\'C!0O[BUWLB57\,]J+
ME?S^__\SW@/7B_X#VHM5",'G'L'N`@O^C903H>O9;HE]](ORB_J+G0#____!
M[AO!YP4+]XM]^#-]_`/>BW7L,WWT`_N-G#>AZ]ENBWWXB_>)70C!YA[![P(+
M]XO[P>\;P>,%B77X"_N+G03___\S\C-U]`/?BWW\`_.-M#ZAZ]ENB_K!YQ[!
MZ@(+^HO6B]Z)??#!ZAO!XP4+TXM=^#/?B[T(____,UT(`_J+5?0#WXV<$Z'K
MV6Z+?0B)7?R+U\'B'L'O`@O7B_O![QO!XP4+^XM=\(E5"#/:BY4,____,]X#
MUXO^`]J+5?C!YQ[![@*-E!.AZ]EN"_Z+\HO:P>X;P>,%"_.+70B)?>PSWXN]
M$/___S-=_`/^BW7P`]^+??R-G#.AZ]ENB_?!YA[![P(+]XO[B5WXB77\P>\;
MP>,%"_N+7>PSWHNU%/___S/:`_>+^@/>BW4(P><>P>H""_J-M#.AZ]ENB7WT
MB]:+_HN=&/___\'J&\'G!0O7BWWX,WW\`]J+5>PS??0#^XV<%Z'KV6Z+??B+
MUXE=",'B'L'O`@O7B57XB_LSUC-5],'O&\'C!0O[BYT<____`]^+??P#TXV4
M.J'KV6Z+_L'G'L'N`@O^B_*+VHE]\,'N&\'C!0OSBUWX,]^+O2#___\S70@#
M_HMU]`/?BWT(C9PSH>O9;HOWP>8>P>\""_>+^XE=_(EU",'O&\'C!0O[BUWP
M,]Z+M23___\SV@/W`]Z+=?B+^L'G'L'J`HVT,Z'KV6X+^HO6B][!ZAO!XP4+
MTXM="(E][#/?B[TH____,UW\`_J+5?`#WXM]_(V<$Z'KV6Z+U\'B'L'O`@O7
MB_N)7?B)5?S![QO!XP4+^XM=[#/:BY4L____,]X#UXO^`]J+50C!YQ[![@(+
M_HV4$Z'KV6Z)??2+\HOZBYTP____P>X;P><%"_>+??@S??P#WHMU[#-]]`/[
MC9PWH>O9;HM]^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BYTT____,_(S
M=?0#WXM]_`/SC;0^H>O9;HOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+7?@S
MWXN]./___S-="`/ZBU7T`]^+?0B-G!.AZ]ENB]?!XA[![P(+UXO[B5W\B54(
MP>\;P>,%"_N+7?`SVHN5//___S/>`]<#VHM5^(V\$Z'KV6Z+UL'B'L'N`@O6
MB_>+W\'N&\'C!0OSBUT(B57L,]J+E4#___\S7?P#UHMU_`/:BU7PC9P3H>O9
M;HO6P>(>P>X""]:+\XE=^(E5_,'N&\'C!0OSBUWL,]J+E43___\SWP/6B_<#
MVHM5",'F'L'O`@OWC903H>O9;HEU](ORB_J+G4C____![AO!YP4+]XM]^#-]
M_`/>BW7L,WWT`_N-M#>AZ]ENBWWXB74(B_?!YA[![P(+]XOZ"WWTBUT(B77X
M(_Z+\B-U],'C!0O^BW4(P>X;"_.+G4S___\#WXM]_`/SC;0^W+P;CXOZP><>
MP>H""_J+UXE]\`M5""-5^"-]"(O>"]>+_L'O&\'C!0O[BYU0____`]J+5?0#
M^XV<%]R\&X^+?0B+UXE=_,'B'L'O`@O7B_J)50@+_B/6(WWP"_J+T\'J&\'C
M!0O3BYU4____`]^+??@#TXV4.MR\&X^+_L'G'L'N`@O^B]J+]XE][`MU_"-]
M_,'C!2-U"`OWB_K![QL+^XN=6/___P/>BW7P`_N-G#?<O!N/BWW\B_>)7?C!
MYA[![P(+]XO^B77\"_HC\B-][`O^B_/![AO!XP4+\XN=7/___P/?BWT(`_.-
MM#[<O!N/B_K!YQ[!Z@(+^HM5_(E]](M=_`O7(U7X(]^+_@O3B][![QO!XP4+
M^XN=8/___P/:BU7L`_N-E!?<O!N/BWWXB54(B]?!XA[![P(+UXO^"WWTBUT(
MB57X(_J+UB-5],'C!0OZBU4(P>H;"].+G63___\#WXM]_`/3C90ZW+P;CXO^
MP><>P>X""_Z+VHOWB7WP"W4((WT(P>,%(W7X"_>+^L'O&PO[BYUH____`]Z+
M=?0#^XV<-]R\&X^+?0B+]XE=_,'F'L'O`@OWB_Z)=0@+^B/R(WWP"_Z+\\'N
M&\'C!0OSBYUL____`]^+??@#\XVT/MR\&X^+^L'G'L'J`@OZB]Z+UXE][`M5
M_"-]_,'C!2-5"`O7B_[![QL+^XN=</___P/:BU7P`_N-G!?<O!N/BWW\B]>)
M7?C!XA[![P(+UXOZB57\"_XCUB-][`OZB]/!ZAO!XP4+TXN==/___P/?BWT(
M`].+7?R-E#K<O!N/B_[!YQ[![@(+_HMU_`OW(]\C=?B)??2+^@OSB]K![QO!
MXP4+^XN=>/___P/>BW7L`_N-M#?<O!N/BWWXB74(B_?!YA[![P(+]XOZ"WWT
MBUT(B77X(_Z+\B-U],'C!0O^BW4(P>X;"_.+G7S___\#WP/SBWW\C;0^W+P;
MCXOZP><>P>H""_J+WHO7B7WP"U4((WT(P>,%(U7X"]>+_L'O&PO[BUV``]J+
M5?0#^XV<%]R\&X^+?0B+UXE=_,'B'L'O`@O7B_J)50@+_B/6(WWP"_J+T\'J
M&\'C!0O3BUV$`]^+??@#TXV4.MR\&X^+_L'G'L'N`@O^B]J+]XE][`MU_"-]
M_,'C!2-U"`OWB_K![QL+^XM=B`/>BW7P`_N-G#?<O!N/BWW\B_>)7?C!YA[!
M[P(+]XO^B77\"_HC\B-][`O^B_/![AO!XP4+\XM=C`/?BWT(`_.+7?R-M#[<
MO!N/B_K!YQ[!Z@(+^HM5_`O7(]\C5?B)??2+_@O3B][![QO!XP4+^XM=D`/:
MBU7L`_N-E!?<O!N/BWWXB54(B]?!XA[![P(+UXO^"WWTBUT(B57X(_J+UB-5
M],'C!0OZBU4(P>H;"].+790#WXM]_`/3C90ZW+P;CXO^P><>P>X""_Z+VHOW
MB7WP"W4((WT(P>,%(W7X"_>+^L'O&PO[BUV8`]Z+=?0#^XV<-]R\&X^+?0B+
M]XE=_,'F'L'O`@OWB_O![QO!XP4+^XM=\#/>B74(,]J+=9P#]XOZ`]Z+=?C!
MYQ[!Z@*-M#/6P6+*"_J+UHO>P>H;P>,%"].+70@SWXE][(M]H#-=_`/ZBU7P
M`]^+??R-G!/6P6+*B]?!XA[![P(+UXO[B5WXB57\P>\;P>,%"_N+7>PSVHM5
MI#/>`]>+_@/:BU4(P><>P>X""_Z-E!/6P6+*B7WTB_*+^HM=J,'N&\'G!0OW
MBWWX,WW\`]Z+=>PS??0#^XV<-];!8LJ+??B+]XE=",'F'L'O`@OWB_O![QO!
MXP6)=?@+^XM=K#/R,W7T`]^+??P#\XVT/M;!8LJ+^L'G'L'J`@OZB]:+WHE]
M\,'J&\'C!0O3BUWX,]^+?;`S70@#^HM5]`/?BWT(C9P3UL%BRHO7P>(>P>\"
M"]>+^XE=_(E5",'O&\'C!0O[BUWP,]J+5;0SW@/7`]J+5?B+_L'G'L'N`HV4
M$];!8LH+_HORB]K![AO!XP4+\XM="(E][#/?BWVX,UW\`_Z+=?`#WXM]_(V<
M,];!8LJ+]\'F'L'O`@OWB_N)7?B)=?S![QO!XP4+^XM=[#/>BW6\,]H#]XOZ
M`]Z+=0C!YQ[!Z@(+^HVT,];!8LJ)??2+UHO^P>H;P><%"]>+??B+7<`S??P#
MVHM5[#-]]`/[C9P7UL%BRHM]^(O7B5T(P>(>P>\""]>+^\'O&\'C!8E5^`O[
MBUW$,]8S5?0#WXM]_`/3C90ZUL%BRHO^P><>P>X""_Z+\HO:B7WPP>X;P>,%
M"_.+7?@SWXM]R#-="`/^BW7T`]^+?0B-G#/6P6+*B_?!YA[![P(+]XO[B5W\
MB74(P>\;P>,%"_N+7?`SWHMUS#/:`_<#WHMU^(OZP><>P>H"C;0SUL%BR@OZ
MB]:+WL'J&\'C!0O3BUT(B7WL,]^+?=`S7?P#^HM5\`/?C9P3UL%BRHM]_(E=
M^(O7P>(>P>\""]>+^\'O&\'C!0O[BUWLB57\,]J+5=0SW@/7B_X#VHM5",'G
M'L'N`@O^C903UL%BRHE]](ORB_J+7=C![AO!YP4+]XM]^#-]_`/>BW7L,WWT
M`_N-G#?6P6+*BWWXB_>)70C!YA[![P(+]XO[P>\;P>,%B77X"_N+7=PS\C-U
M]`/?BWW\`_.-M#[6P6+*B_K!YQ[!Z@(+^HO6B]Z)??#!ZAO!XP4+TXM=^#/?
MBWW@,UT(`_J+5?0#WXM]"(V<$];!8LJ+U\'B'L'O`@O7B5W\B54(B_O![QO!
MXP4+^XM=\#/:BU7D,]X#UP/:BU7XB_[!YQ[![@*-E!/6P6+*BUT("_Z+\HE5
M]#/?P>X;P>(%"_*+5?PSV@/.`]F+3?`#7>B+=?2-C`O6P6+*B0B+2`0#SHE(
M!(O*P>$>P>H""\J+50@#2`B)2`B+2`P#SU^)2`R+2!`#REZ)2!!;R<-5B^Q3
M5HMU#(M&&(M>%(E%#(O#P>@#@^`_QD0P'(!`@_@X?BIJ0%DKR(U$,!Q1:@!0
MZ+`(``!6Z(WM__]J.(U&'&H`4.B="```@\0<ZQ5J.%DKR(U$,!Q1:@!0Z(8(
M``"#Q`R+10Q6B\B(1E?!Z1B(3E2+R,'I$(A.58O(B\/_=0C!Z!B(1EB+P\'H
M$(A&68O#P>D(P>@(B$Y6B$9:B%Y;Z`8```!965Y;7<-6BW0D#%;H$^W__XM$
M)`Q9BP[!Z1B("(L.P>D0B$@!BP[!Z0B(2`**#HA(`XM6!(U.!,'J&(A0!(L1
MP>H0B%`%BQ'!Z@B(4`:*"8A(!XM6"(U.",'J&(A0"(L1P>H0B%`)BQ'!Z@B(
M4`J*"8A("XM6#(U.#,'J&(A0#(L1P>H0B%`-BQ'!Z@B(4`Z*"8A(#XM6$(U.
M$%[!ZAB(4!"+$<'J$(A0$8L1P>H(B%`2B@F(2!/#5NB5!@``4.BA!@``BS#H
MB`8``%#HC@8``%E94/]T)`SH=@8``%#H@@8``%G_,/]64(/$#(7`=4KH7@8`
M`%#H9`8``&:+0`999B4`\&8]`$!U,.A$!@``4.A0!@``BS!9:@+_="0,Z#`&
M``!0Z#P&``!9_S#_%H/$#(7`=05J`5A>PS/`7L-6BW0D"%=6Z,?A__]0Z)?A
M__]9B_A9Z)_C__^%P'0HA?9T)%;HF@8``(7`6709:.RQ0`!7_Q6(0$``63O'
M674'5N@$````65]>PX'L'`$``%.+G"0D`0``5E>%VP^$)@$``%/H6P8``(7`
M60^$%P$``%/H3`8``(OP@<8"`0``Z)$%``!0Z*,%``"+.%E95NB!!0``4.B3
M!0``6?\P_Q>+\%-H6+)``%;_%:A`0`"-1"0D4%;_%4A`0`"#Q!R#^/^)1"0,
M#X2^````58LM3$!``.L'BYPD,`$``(L]B$!``(U$)"AH(+!``%#_UUF%P%F-
M1"0H4'424VA0LD``5O\5J$!``(/$$.L/:$RR0`!6_Q6H0$``@\0,NTBR0`!3
M5O_7B_A9A?]9=!Y35^B-!0``687`670?:$2R0`!7Z'P%``!9A<!9=`[V1"04
M$'1$5NCV_O__68U$)!10_W0D%/\54$!``%F%P%D/A&7_____="00_Q540$``
M_[0D-`$``/\5I$!``%E975]>6X'$'`$``,.-1"0H4/\5#$!``(OX,]M6_]6%
MP%ETK(O#0X/X"GVDA?]T[%?_%1!`0`#KXU&#9"0``%-65^A)!```4.B=!```
M:@%;B!C'!"0LL4``Z)G=__^%P%ET"X`X,74&@'@!`'0%Z&'@__]J"E-HQ+)`
M`.@0!```4.A>!```@\00A<`/A)T```"+`#D=&+=``%6+\XM`((MX$'Y>O0``
M!`"-1O]J`%!7Z-L#``!0Z",$``"#Q!"%P'1`BP"+2`@CS3O-=0:+`(L`ZPY0
MZ+<#``!0Z/D#``!965"A'+=``/\TL.A)!```687`674-_T0D$$8[-1BW0`!\
MIZ$8MT``78U(_SE,)`QU'3O#B_-^%U?H<P,``%#HKP,``$99.S48MT``67SI
M:@13:,"R0`#H50,``%#HHP,``(OP@\00A?9T-8L&:+2R0`"+0"#_,.@U`P``
M4.AK`P``BP:#Q`R+0""+`/9`"4!T#E#H&0,``%#H20,``%E9:@13:+"R0`#H
M!`,``%#H4@,``(OP@\00A?9T<FA8L$``Z%+<__^%P%ET`U#K2^B$VO__B_B%
M_W0YBP97BT`@_S#HRP(``%#H`0,``.C``@``4.C2`@``BS"#Q!!7Z*\"``!0
MZ,$"``!9_S#_5@A96>L<H1RW0`#_,(L&BT`@_S#HC`(``%#HP@(``(/$#.A^
M`@``4.C2`@``@"``Z'`"``!0Z)H"``"#(`!H:+!``.C$V___@\0,HQ2S0`"%
MP'41_S4<MT``Z"CA__]9HQ2S0`#H.P(``%#H7P(``(LPQP0D[0$``/\U%+-`
M`.@A`@``4.A%`@``6?\P_Q:#Q`R%P%]>6W0E@_@1=""#^/]T&U"A'+=``/\U
M%+-``/\P:&"R0`#H#@(``(/$$%G#58OL5HU%#%=0C44(4/\5L$!``#/_5^AF
M`@``@\0,@#@`=4OH4P(``#O'HQ"S0`!U(^BO`0``4.C'`0``BS!9:@'HGP$`
M`%#HMP$``%G_,/]6"%E9_S40LT``Z!8"``#H@0$``%#H!0(``%F).%GH<@$`
M`%#H\`$``(`(`8M%"(T$A10```!0Z-<!``!9HQRW0`!9BTT,:@&+"8D(H1RW
M0`#'0`30LD``H1RW0`#'0`A,04``H1RW0`#'!1BW0``#````QT`,S+)``/\%
M&+=``%@Y10A^'HL-&+=``(M5#(LU'+=```/(BQ2"0(E4COP[10A\XJ$8MT``
MBTT(`\&+#1RW0`!7B7R!_(M%"(L-&+=``/\U'+=``(U$`?]0:#<X0`#_-1"S
M0`#H,`$``(OP@\04._=U#O\U$+-``.@6`0``68OP_S40LT``Z`(!``#'!"0@
ML4``Z/'9__^%P%EU)*$4LT``.\=U%&AHL$``Z-G9__\[QUFC%+-``'0'4.A-
M^O__6?\U$+-``.B\````5^BP````65E0_Q4(0$``B\9?7EW#Z#P```!0Z+[7
M__]9N"2W0`!04&@A-$``:-2R0`#H'P```%#H$P```(/$$%#H$````%#H1@``
M`(/$#,/_)2!!0`#_)1Q!0`#_)1A!0`#_)11!0`#_)1!!0`#_)0Q!0`#_)0A!
M0`#_)01!0`#_)0!!0`#_)?Q`0`#_)?A`0`#_)?1`0`#_)?!`0`#_)>Q`0`#_
M)>A`0`#_)>1`0`#_)>!`0`#_)=Q`0`#_)=A`0`#_)=1`0`#_)=!`0`#_)<Q`
M0`#_)<A`0`#_)<1`0`#_)<!`0`#_);Q`0`#_);A`0`#_);1`0`#,S,S,S,S_
M)91`0`#_)8Q`0`#,S,S,43T`$```C4PD"'(4@>D`$```+0`0``"%`3T`$```
M<^PKR(O$A0&+X8L(BT`$4,/,_R5@0$``_R5<0$``58OL:O]H\)U``&B@.D``
M9*$`````4&2))0````"#["!35E>)9>B#9?P`:@'_%9A`0`!9@PTXMT``_X,-
M/+=``/__%5A`0`"+#32W0`")"/\5'$!``(L-,+=``(D(H2!`0`"+`*-`MT``
MZ,````"#/0"S0```=0QH'A!``/\5)$!``%GHE````&@,L$``:`BP0`#H?P``
M`*$LMT``B478C4784/\U*+=``(U%X%"-1=10C47D4/\5+$!``&@$L$``:`"P
M0`#H3````/\5,$!``(M-X(D(_W7@_W74_W7DZ$3\__^#Q#")1=Q0_Q4T0$``
MBT7LBPB+"8E-T%!1Z`\```!96<.+9>C_==#_%3Q`0`#_)3A`0`#_)2A`0`!H
M```#`&@```$`Z`\```!96</#S,S,S,S_)9Q`0`#_):!`0```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````*B````````W*$``,BA``"ZH0``I*$```````":HP``BJ,``':C``!J
MHP``6J,``$JC``!"HP``-*,``"RC```4HP``"J,``/RB``#RH@``YJ(``-BB
M``"JHP``Q*(``+JB``"JH@``GJ(``)2B``"*H@``@*(``':B``!LH@``8J(`
M`%*B``!(H@``/J(``#2B```JH@``N*,``,JC``#>HP``SJ(``""B````````
MAJ$``'"A``!BH0``4*$``#"A```8H0```J$``/2@``#HH```V*```,R@``"V
MH```HJ```)"@``"`H```;*```%R@``!,H```/J```"J@```:H````J```/"?
M``#@GP``T)\``+R?``"JGP``EI\``(B?````````````````````````:B#6
M20`````"````.P``````````X```(R$O=7-R+V)I;B]P97)L#0H-"F5V86P@
M)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PT*("`@(&EF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`T*#0IP86-K86=E
M(%]?<&%R7W!L.PT*#0HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@
M86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0T*(R!U<V4@<W1R:6-T
M.PT*#0HC;&EN92`Q-3D-"@T*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92D[#0I%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![#0H@("`@
M<F5Q=6ER92!&:6QE.CI496UP.PT*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64[#0H@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PT*("`@(&UY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PT*("`@(&]U
M=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L-"B`@("!&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L-"B`@("!R;61I<B`D<&%R7W1E;7`[#0H@
M("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@
M82!R86-E('=I=&@@;W1H97(@87!P<PT*("`@(",@=&AA="!A<F4@=')Y:6YG
M('1O('-T87)T+@T*#0H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2![#0H@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@
M=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PT*("`@
M("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I
M<V%L;&]W('5N;&EN:VEN9R!S:&%R960-"B`@("`@("`@(R!L:6)R87)I97,@
M86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@
M82!B86-K9W)O=6YD#0H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@
M9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@T*
M("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S
M92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`T*("`@("`@("`C('1A:V4@8V%R
M92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N#0H-"B`@("`@("`@;7D@)'1M<"`]
M(&YE=R!&:6QE.CI496UP*`T*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP-"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P-"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M
M9"<L#0H@("`@("`@("`@("!53DQ)3DL@/3X@,"P-"B`@("`@("`@*3L-"@T*
M("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@-"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O#0H@("!R;2`M<F8@)R1P87)?=&5M<"<-"B`@(&EF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@T*("`@("`@(&)R96%K#0H@
M("!F:0T*("`@<VQE97`@,0T*("`@>#U@97AP<B!<)'@@*R`Q8`T*9&]N90T*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G#0HB.PT*("`@("`@("`@("`@
M8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L-"B`@("`@("`@;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[#0H@("`@
M("`@(&-L;W-E("1T;7`[#0H@("`@("`@('-Y<W1E;2@D8VUD*3L-"B`@("`@
M("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("D-"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE
M*3L-"B`@("!]#0I]('T-"@T*0D5'24X@>PT*("`@($EN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[#0H-
M"B`@("!E=F%L('L-"@T*7W!A<E]I;FET7V5N=B@I.PT*#0II9B`H97AI<W1S
M("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2![#0H@
M("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.
M5GM005)?05)'0WT@+2`Q*3L-"B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T[
M#0I]#0IE;'-E('L-"B`@("!F;W(@*&ME>7,@)45.5BD@>PT*("`@("`@("!D
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PT*("`@('T-"GT-"@T*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L-"@T*(R!F:7@@)'!R;V=N
M86UE(&EF(&EN=F]K960@9G)O;2!0051(#0IM>2`E0V]N9FEG(#T@*`T*("`@
M('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`T*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL#0H@("`@7V1E;&EM("`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P-"BD[#0H-"E]S
M971?<')O9VYA;64H*3L-"E]S971?<&%R7W1E;7`H*3L-"@T*(R!-86=I8R!S
M=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S
M('M[>PT*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD[#0I[#0H@("`@;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[#0H-"B`@("`C($-H96-K(&9I
M;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL-"B`@("!O
M<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L-"B`@("!B:6YM;V1E
M*%]&2"D[#0H-"B`@("!M>2`D8G5F.PT*("`@('-E96L@7T9(+"`M."P@,CL-
M"B`@("!R96%D(%]&2"P@)&)U9BP@.#L-"B`@("!L87-T('5N;&5S<R`D8G5F
M(&5Q(")<;E!!4BYP;5QN(CL-"@T*("`@('-E96L@7T9(+"`M,3(L(#([#0H@
M("`@<F5A9"!?1D@L("1B=68L(#0[#0H@("`@<V5E:R!?1D@L("TQ,B`M('5N
M<&%C:R@B3B(L("1B=68I+"`R.PT*("`@(')E860@7T9(+"`D8G5F+"`T.PT*
M#0H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0[#0H@("`@(R!]?7T-
M"@T*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM[
M#0H@("`@;7D@)7)E<75I<F5?;&ES=#L-"B`@("!W:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L-"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[#0H@("`@("`@
M(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L-"@T*("`@("`@
M("!M>2`D9G5L;&YA;64@/2`D8G5F.PT*("`@("`@("!O=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D[#0H@("`@("`@(&UY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968[#0H@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@
M/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L-"@T*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@-#L-"B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PT*#0H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PT*("`@("`@("`@("`@
M;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[
M#0H@("`@("`@("`@("!I9B`H)&]U="D@>PT*("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&]U="D[#0H@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F
M.PT*("`@("`@("`@("`@("`@(&-L;W-E("1O=70[#0H@("`@("`@("`@("`@
M("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PT*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PT*("`@("`@("!]#0H@("`@("`@
M(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L-"B`@("`@("`@("`@(",@<VAO=6QD(&)E
M(&UO=F5D('1O(%]T96UP9FEL92@I#0H@("`@("`@("`@("!M>2`D9FEL96YA
M;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="([#0H@("`@("`@
M("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L-"B`@("`@("`@("`@
M(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PT*("`@
M("`@("`@("`@8FEN;6]D92@D;W5T*3L-"B`@("`@("`@("`@('!R:6YT("1O
M=70@)&)U9CL-"B`@("`@("`@("`@(&-L;W-E("1O=70[#0H@("`@("`@('T-
M"B`@("`@("`@96QS92![#0H@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97T@/0T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2![#0H@("`@("`@("`@("`@("`@8G5F(#T^("1B
M=68L#0H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L#0H@("`@("`@("`@
M("`@("`@;F%M92`]/B`D9G5L;&YA;64L#0H@("`@("`@("`@("!].PT*("`@
M("`@("!]#0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PT*("`@('T-"B`@
M("`C('U]?0T*#0H@("`@;&]C86P@0$E.0R`]("AS=6(@>PT*("`@("`@("!M
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[#0H-"B`@("`@("`@<F5T=7)N(&EF
M(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PT*#0H@("`@("`@(&UY("1F:6QE
M;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L-
M"B`@("`@("`@("`@(&UY("1K97D[#0H@("`@("`@("`@("!F;W)E86-H("AK
M97ES("5R97%U:7)E7VQI<W0I('L-"B`@("`@("`@("`@("`@("!N97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL-"B`@("`@("`@("`@("`@("`D:V5Y(#T@
M)%\[(&QA<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!D96QE=&4@
M)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PT*("`@("`@
M("!](&]R(')E='5R;CL-"@T*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PT*#0H@("`@("`@(&EF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![#0H@
M("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE("0A.PT*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PT*("`@("`@("`@
M("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT[#0H@("`@("`@("`@("!S
M965K*"1F:"P@,"P@,"D[#0H@("`@("`@("`@("!R971U<FX@)&9H.PT*("`@
M("`@("!]#0H@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@;7D@*"1O=70L
M("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D[
M#0H@("`@("`@("`@("!I9B`H)&]U="D@>PT*("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&]U="D[#0H@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL
M96YA;64M/GMB=69].PT*("`@("`@("`@("`@("`@(&-L;W-E("1O=70[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D
M;F%M92!O<B!D:64@)"$[#0H@("`@("`@("`@("!B:6YM;V1E*"1F:"D[#0H@
M("`@("`@("`@("!R971U<FX@)&9H.PT*("`@("`@("!]#0H-"B`@("`@("`@
M9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L
M92%<;B([#0H@("`@?2P@0$E.0RD[#0H-"B`@("`C($YO=R!L;V%D(&%L;"!B
M=6YD;&5D(&9I;&5S('M[>PT*#0H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O
M8FIE8W0@<')O8V5S<VEN9PT*("`@(')E<75I<F4@6%-,;V%D97([#0H@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PT*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD[
M#0H@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[#0H@("`@4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PT*#0H@("`@(R!N;W<@;&5T)W,@=')Y
M(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X-"B`@("!R97%U
M:7)E($E/.CI&:6QE.PT*#0H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P
M(&EN#0H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L-"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL-"B`@("`@("`@
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2![#0H@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H
M97(@97AE8W5T86)L92!F:6QE<PT*("`@("`@("`@("`@:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER92`D
M9FEL96YA;64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!E;'-E('L-
M"B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S
M=&]M:7IE+G!L(&9I;&4Z#0H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&9I;&5N86UE?3L-"B`@("!]#0H-"B`@("`C('U]?0T*#0H@
M("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([#0H@("`@)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PT*?0T*(R!]?7T-"@T*(R!!<F=U
M;65N="!P<F]C97-S:6YG('M[>PT*;7D@0'!A<E]A<F=S.PT*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PT*#0HD<75I970@/2`P
M('5N;&5S<R`D14Y6>U!!4E]$14)51WT[#0H-"B,@1&]N)W0@<W=A;&QO=R!A
M<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP
M87(M;W!T:6]N<PT*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![#0H@("`@;7D@)61I<W1?8VUD
M(#T@<7<H#0H@("`@("`@('`@("!B;&EB7W1O7W!A<@T*("`@("`@("!I("`@
M:6YS=&%L;%]P87(-"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(-"B`@("`@
M("`@<R`@('-I9VY?<&%R#0H@("`@("`@('8@("!V97)I9GE?<&%R#0H@("`@
M*3L-"@T*("`@(&UY($!A9&1?=&]?:6YC.PT*("`@('=H:6QE("A`05)'5BD@
M>PT*("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PT*#0H@("`@("`@(&EF("@D,2!E<2`G22<I('L-"B`@
M("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PT*("`@("`@("!]#0H@
M("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L-"B`@("`@("`@("`@(&5V86P@
M(G5S92`D,B([#0H@("`@("`@('T-"B`@("`@("`@96QS:68@*"0Q(&5Q("=!
M)RD@>PT*("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PT*("`@
M("`@("!]#0H@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L-"B`@("`@("`@
M("`@("1O=70@/2`D,CL-"B`@("`@("`@?0T*("`@("`@("!E;'-I9B`H)#$@
M97$@)V(G*2![#0H@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PT*("`@
M("`@("!]#0H@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L-"B`@("`@("`@
M("`@("1B=6YD;&4@/2`G86QL)SL-"B`@("`@("`@?0T*("`@("`@("!E;'-I
M9B`H)#$@97$@)W$G*2![#0H@("`@("`@("`@("`D<75I970@/2`Q.PT*("`@
M("`@("!]#0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L-"B`@("`@("`@
M("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T
M(&]P96X@;&]G.B`D(2([#0H@("`@("`@('T-"B`@("`@("`@96QS:68@*"0Q
M(&5Q("=4)RD@>PT*("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL-"B`@
M("`@("`@?0T*#0H@("`@("`@('-H:69T*$!!4D=6*3L-"@T*("`@("`@("!I
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L-"B`@("`@("`@("`@(&1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PT*("`@("`@("`@("`@:6YI=%]I;F,H
M*3L-"B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PT*("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[#0H@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PT*
M("`@("`@("`@("`@97AI=#L-"B`@("`@("`@?0T*("`@('T-"@T*("`@('5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[#0I]#0H-"B,@6%A8("TM(&%D9"`M
M+7!A<BUD96)U9R!S=7!P;W)T(0T*#0HC('U]?0T*#0HC($]U='!U="!M;V1E
M("@M3RD@:&%N9&QI;F<@>WM[#0II9B`H)&]U="D@>PT*("`@('L-"B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL-"B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L-"B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`[#0H@("`@?0T*#0H@("`@;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L-"B`@("!M>2`D>FEP.PT*#0H-"B`@("!I9B`H
M9&5F:6YE9"`D<&%R*2![#0H@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P
M87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL-"B`@("`@("`@
M8FEN;6]D92@D9F@I.PT*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PT*#0H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL-"B`@("`@
M("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0T*("`@("`@("`@("`@;W(@9&EE(")2
M96%D("<D<&%R)R!E<G)O<CH@)"$B.PT*("`@('T-"@T*#0H@("`@;7D@)65N
M=B`](&1O('L-"B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II
M<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L-"B`@("`@("`@("`@("1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PT*("`@("`@("`@("`@)&UE=&$@/7X@<R]>
M7%,N*B\O;7,[#0H@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<[#0H@("`@("`@('T-"B`@("!].PT*#0H@("`@(R!/<&5N(&EN
M<'5T(&%N9"!O=71P=70@9FEL97,@>WM[#0H@("`@;&]C86P@)"\@/2!<-#L-
M"@T*("`@(&EF("AD969I;F5D("1P87(I('L-"B`@("`@("`@;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL-"B`@("`@("`@8FEN;6]D
M92A005(I.PT*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"([#0H@("`@?0T*#0H@("`@
M0W)E871E4&%T:"@D;W5T*2`[#0H@("`@#0H@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@-"B`@("`@("`@)&]U="P-"B`@("`@("`@24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P-"B`@("`@("`@,#<W-RP-"B`@("`I(&]R(&1I92`D(3L-"B`@
M("!B:6YM;V1E*"1F:"D[#0H-"B`@("`D+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[#0H@("`@<V5E:R!?1D@L(#`L(#`[
M#0H@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL-"B`@("!I9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L-"B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M#0H@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I#0H@("`@?0T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L-"B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L-"B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\[#0H@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL-"B`@("`@("`@;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL-"B`@("`@("`@)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PT*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI#0H@("`@("`@('UE9SL-
M"B`@("!]#0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L-"B`@("`D+R`]('5N
M9&5F.PT*("`@(",@?7U]#0H-"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE
M<R![>WL-"B`@("!I9B`H)&)U;F1L92D@>PT*("`@("`@("!R97%U:7)E(%!!
M4CHZ2&5A=GD[#0H@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L-"B`@("`@("`@:6YI=%]I;F,H*3L-"@T*("`@("`@("!R97%U:7)E
M7VUO9'5L97,H*3L-"@T*("`@("`@("!M>2!`:6YC(#T@<V]R="![#0H@("`@
M("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I#0H@("`@("`@('T@
M9W)E<"![#0H@("`@("`@("`@("`A+T)31%!!3B\-"B`@("`@("`@?2!G<F5P
M('L-"B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(-"B`@("`@
M("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M#0H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L-"B`@("`@("`@?2!`24Y#.PT*#0H@("`@("`@(&EF("@D0V]N9FEG
M>U]D96QI;7T@97$@)UQ<)RD@>R!S>UQ<?7LO?6<@9F]R($!I;F,@?0T*#0H@
M("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q
M-SDP.@T*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@
M7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N#0H@
M("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E
M<B!G<F%S<"!O9B!T:&4@:7-S=64N#0H@("`@("`@(",@4V]M96)O9'D@<&QE
M87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T
M)W,@:&%P<&5N:6YG+`T*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N
M#0H@("`@("`@(&UY("5F:6QE<SL-"B`@("`@("`@+UY?/"@N*RDD+R!A;F0@
M+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH[#0H@("`@("`@
M("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,[#0H-"B`@("`@("`@;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[#0H@("`@("`@
M(&UY("5W<FET=&5N.PT*#0H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E
M9FEL97,I('L-"B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PT*#0H@
M("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L-"B`@("`@("`@
M("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1?
M?2D@>PT*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PT*("`@("`@
M("`@("`@("`@("`@("!L87-T.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I
M*2![#0H@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD[#0H@("`@("`@("`@("`@("`@("`@(&QA<W0[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>
M+UTK+R@N*EM>0V-=*5Q:(2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF
M("(D9&ER+R0Q(BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!L87-T.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!N97AT
M('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]
M*RL[#0H@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+SL-"B`@("`@("`@("`@(&]U=',H(&IO
M:6X@(B(L#0H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`T*("`@("`@("`@("`@("`@
M('%Q*"(N+BXI#0H@("`@("`@("`@("`I.PT*#0H@("`@("`@("`@("!M>2`D
M8V]N=&5N=#L-"B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2![#0H@("`@
M("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!E;'-E('L-"B`@("`@("`@("`@("`@("!O
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2([#0H@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L-"B`@("`@
M("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL-"B`@("`@("`@("`@("`@
M("!C;&]S92!&24Q%.PT*#0H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I#0H@("`@
M("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L-"@T*("`@("`@("`@("`@("`@
M(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N
M=FER;VYM96YT#0H@("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O
M("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\-"B`@("`@("`@("`@
M("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PT*
M("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@
M87,@(B1N86UE(BDI.PT*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I
M.PT*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI*3L-"B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@-
M"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64-"B`@("`@("`@("`@("DI.PT*
M("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DI.PT*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D[#0H@
M("`@("`@('T-"B`@("!]#0H@("`@(R!]?7T-"@T*("`@(",@3F]W('=R:71E
M(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PT*("`@("1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L-"@T*("`@("1C86-H
M95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L-"B`@("!I9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L-"B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T-"B`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L-"@T*("`@("`@("`C(%=O<FMA<F]U;F0@
M9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y#0H@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PT*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![#0H@("`@("`@("`@("`D
M8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PT*("`@("`@("!]
M#0H@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PT*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L-"B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D[
M#0H@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*#0H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM93L-"B`@("!]#0H@("`@)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D[#0H@("`@
M)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL-"B`@("`D9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L-"B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L-"B`@("`D9F@M/G!R:6YT*")<;E!!4BYP
M;5QN(BD[#0H@("`@)&9H+3YC;&]S93L-"B`@("!C:&UO9"`P-S4U+"`D;W5T
M.PT*("`@(",@?7U]#0H-"B`@("!E>&ET.PT*?0T*(R!]?7T-"@T*(R!0<F5P
M87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PT*>PT*("`@
M(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL-"@T*("`@(%]F:7A?
M<')O9VYA;64H*3L-"@T*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N
M9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PT*("`@(')E<75I<F4@
M4$%2.PT*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L-"@T*
M#0H@("`@>PT*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)
M3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PT*("`@("`@("!R97%U:7)E($9I
M;&4Z.D9I;F0[#0H@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PT*("`@
M('T-"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[#0H@("`@;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL-"B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([#0H@("`@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PT*#0H@("`@<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L-"B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M(#T@)'II<#L-"@T*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[#0H@
M("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D[#0H-"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$-"B`@("`@("`@9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L-"B`@("`@("`@("`@(&YE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[#0H@("`@("`@("`@("!M>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L-"B`@("`@("`@("`@
M(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PT*("`@("`@("`@("`@
M("`@(%X-"B`@("`@("`@("`@("`@("`O/W-H;&EB+PT*("`@("`@("`@("`@
M("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PT*("`@("`@("`@
M("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\-"B`@("`@
M("`@("`@("`@("`H6UXO72LI#0H@("`@("`@("`@("`@("`@)`T*("`@("`@
M("`@("`@?7@[#0H@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$[
M#0H@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[#0H@("`@("`@
M("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PT*("`@("`@("`@("`@("`@(&]U=',H<7$H
M4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES
M=',@870@(B1D97-T7VYA;64B*2D[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L-"B`@("`@("`@("`@("`@("`D;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[#0H@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"B`@("`C
M('U]?0T*?0T*(R!]?7T-"@T*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@
M<G5N+"!S:&]W('5S86=E('M[>PT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2![#0H@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[#0I5
M<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=
M(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=#0H@("`@("`@)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(-"BX-"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L-"GT-"B,@
M?7U]#0H-"G-U8B!#<F5A=&50871H('L-"B`@("!M>2`H)&YA;64I(#T@0%\[
M#0H@("`@#0H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L-"B`@("!M>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[#0H@("`@#0H@("`@<F5Q=6ER92!&
M:6QE.CI0871H.PT*("`@(`T*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M#0I]#0H-"G-U8B!R97%U:7)E7VUO9'5L97,@>PT*("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[#0H-
M"B`@("!R97%U:7)E(&QI8CL-"B`@("!R97%U:7)E($1Y;F%,;V%D97([#0H@
M("`@<F5Q=6ER92!I;G1E9V5R.PT*("`@(')E<75I<F4@<W1R:6-T.PT*("`@
M(')E<75I<F4@=V%R;FEN9W,[#0H@("`@<F5Q=6ER92!V87)S.PT*("`@(')E
M<75I<F4@0V%R<#L-"B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PT*("`@(')E
M<75I<F4@17)R;F\[#0H@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[#0H@
M("`@<F5Q=6ER92!%>'!O<G1E<CL-"B`@("!R97%U:7)E($9C;G1L.PT*("`@
M(')E<75I<F4@1FEL93HZ5&5M<#L-"B`@("!R97%U:7)E($9I;&4Z.E-P96,[
M#0H@("`@<F5Q=6ER92!84TQO861E<CL-"B`@("!R97%U:7)E($-O;F9I9SL-
M"B`@("!R97%U:7)E($E/.CI(86YD;&4[#0H@("`@<F5Q=6ER92!)3SHZ1FEL
M93L-"B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PT*("`@(')E<75I<F4@
M07)C:&EV93HZ6FEP.PT*("`@(')E<75I<F4@4$%2.PT*("`@(')E<75I<F4@
M4$%2.CI(96%V>3L-"B`@("!R97%U:7)E(%!!4CHZ1&ES=#L-"B`@("!R97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L-"B`@("!E=F%L('L@<F5Q=6ER
M92!#=V0@?3L-"B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PT*("`@(&5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PT*("`@(&5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PT*("`@(&5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[#0I]#0H-"B,@5&AE($,@
M=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I
M<BYC#0HC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP
M(&%S('-E=%]P87)?=&5M<%]E;G8A#0IS=6(@7W-E=%]P87)?=&5M<"![#0H@
M("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PT*("`@("`@("`D<&%R7W1E;7`@/2`D,3L-"B`@
M("`@("`@<F5T=7)N.PT*("`@('T-"@T*("`@(&9O<F5A8V@@;7D@)'!A=&@@
M*`T*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P-"B`@("`@("`@<7<H($,Z7%Q414U0
M("]T;7`@+B`I#0H@("`@*2![#0H@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L-"B`@("`@("`@
M;7D@)'5S97)N86UE.PT*("`@("`@("!M>2`D<'=U:60[#0H@("`@("`@(",@
M9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@T*("`@("`@("!E=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[#0H-"B`@("`@
M("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L-"B`@("`@
M("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PT*("`@("`@
M("!]#0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PT*("`@("`@
M("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PT*("`@("`@("!]#0H@("`@("`@
M(&5L<V4@>PT*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL-"B`@("`@("`@?0T*("`@
M("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<[#0H-"B`@("`@("`@;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL-
M"B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34[#0H@("`@("`@(&EF("@A
M)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA
M;64I*5LY72D@>PT*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P
M<F]G;F%M92D[#0H@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PT*("`@
M("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8[#0H@("`@("`@("`@
M("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L-"B`@("`@("`@("`@("`@("!S
M965K("1F:"P@+34X+"`R.PT*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L-"B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<[
M#0H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`D8G5F.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M96QS92![#0H@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T-"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]#0H@("`@("`@("`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T[#0H-"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I
M;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y#0H@("`@("`@("`@("`@("`@
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`[#0H@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I
M9B`H)&-T>"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1C='@M/F%D9&9I;&4H)&9H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-L;W-E*"1F:"D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM92`I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@8VQO
M<V4H)&9H*3L-"B`@("`@("`@?0T*("`@("`@("!E;'-E('L-"B`@("`@("`@
M("`@("1%3E9[4$%27T-,14%.?2`](#$[#0H@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([#0H@("`@("`@('T-"@T*
M("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PT*("`@("`@("!M
M:V1I<B`D<W1M<&1I<BP@,#<U-3L-"B`@("`@("`@;&%S=#L-"B`@("!]#0H-
M"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PT*?0T*#0IS=6(@7W1E;7!F:6QE('L-
M"B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL-"B`@("!M>2`H)&9H+"`D9FEL
M96YA;64I.PT*#0H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X
M="([#0H-"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2![#0H@("`@("`@('5N
M;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PT*("`@("`@("!P=7-H
M($!T;7!F:6QE+"`D9FEL96YA;64[#0H@("`@?0T*("`@(&5L<V4@>PT*("`@
M("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA
M;64I.PT*("`@('T-"@T*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O
M<B!D:64@)"$[#0H@("`@8FEN;6]D92@D9F@I.PT*("`@(')E='5R;B@D9F@L
M("1F:6QE;F%M92D[#0I]#0H-"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ
M4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE#0IS=6(@7W-E=%]P<F]G;F%M
M92![#0H@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![#0H@("`@("`@("1P<F]G
M;F%M92`]("0Q.PT*("`@('T-"@T*("`@("1P<F]G;F%M92!\?#T@)#`[#0H-
M"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L-"B`@("`@("`@)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`K(#$I.PT*("`@('T-"@T*("`@(&EF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2![#0H@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L-"B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PT*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[#0H@
M("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2![#0H@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PT*("`@("`@
M("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL-"B`@("`@("`@
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D-"B`@("`@("`@("`@(&EF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([#0H@("`@
M("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D-"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL-"B`@("!]#0I]#0H-"G-U8B!?9FEX7W!R;V=N
M86UE('L-"B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PT*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/"`P*2![#0H@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL-"B`@("!]#0H-"B`@("`C(%A86"`M(&AA8VL@=&\@
M;6%K92!05T0@=V]R:PT*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0T*("`@("`@("`@("`@("`@(#H@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L-"B`@("!C:&]M<"@D<'=D*3L-"B`@("`D<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL-"@T*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L-
M"GT-"@T*<W5B(%]P87)?:6YI=%]E;G8@>PT*("`@(&EF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L-"B`@("`@("`@<F5T=7)N.PT*("`@
M('T@96QS92![#0H@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M#0H@("`@?0T*#0H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2![#0H@("`@("`@
M(&1E;&5T92`D14Y6>R=005)?)RXD7WT[#0H@("`@?0T*("`@(&9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L-"B`@("`@("`@)$5.5GLG
M4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??3L-"B`@("!]#0H-"B`@("!M>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL-
M"@T*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PT*("`@("`@("!D96QE=&4@
M)$5.5GM005)?0TQ%04Y].PT*("`@('T-"B`@("!E;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![#0H@("`@("`@(&UY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[#0H@
M("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!
M4E]#3$5!3CTH7%,K*2\[#0H@("`@?0T*?0T*#0IS=6(@;W5T<R![#0H@("`@
M<F5T=7)N(&EF("1Q=6EE=#L-"B`@("!I9B`H)&QO9V9H*2![#0H@("`@("`@
M('!R:6YT("1L;V=F:"`B0%]<;B([#0H@("`@?0T*("`@(&5L<V4@>PT*("`@
M("`@("!P<FEN="`B0%]<;B([#0H@("`@?0T*?0T*#0IS=6(@:6YI=%]I;F,@
M>PT*("`@(')E<75I<F4@0V]N9FEG.PT*("`@('!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H#0H@("`@("`@
M(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M#0H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP#0H@("`@*3L-
M"GT-"@T*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C#0HC(%1H92!M86EN
M('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX-"@T*<&%C:V%G92!M86EN
M.PT*#0IR97%U:7)E(%!!4CL-"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PT*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L-"@T*9&EE('%Q*'!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0T*("`@('5N;&5S<R`M92`D<')O9VYA
M;64[#0H-"F1O("1P<F]G;F%M93L-"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD[#0ID:64@)$`@:68@)$`[#0H-"GT[
M#0H-"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L-"GT-"@T*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PT*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL-"@T*,3L-"@T*(VQI;F4@
M,3`P,@T*#0I?7T5.1%]?#0H``````/____]<.D``<#I``!"?````````````
M`)BA``"P0```:)X`````````````]*$```A```!@G@`````````````2H@``
M`$```'R>`````````````""C```<0``````````````````````````````"
MH@```````-RA``#(H0``NJ$``*2A````````FJ,``(JC``!VHP``:J,``%JC
M``!*HP``0J,``#2C```LHP``%*,```JC``#\H@``\J(``.:B``#8H@``JJ,`
M`,2B``"ZH@``JJ(``)ZB``"4H@``BJ(``("B``!VH@``;*(``&*B``!2H@``
M2*(``#ZB```TH@``*J(``+BC``#*HP``WJ,``,ZB```@H@```````(:A``!P
MH0``8J$``%"A```PH0``&*$```*A``#TH```Z*```-B@``#,H```MJ```**@
M``"0H```@*```&R@``!<H```3*```#Z@```JH```&J````*@``#PGP``X)\`
M`-"?``"\GP``JI\``):?``"(GP```````-0"4&5R;%]N97=84P``&0)097)L
M7V=E=%]C;VYT97AT``#+`V)O;W1?1'EN84QO861E<@"S`5!E<FQ?5'-T871B
M=69?<'1R`$\`4&5R;%])3$E/7W!T<@!2`%!E<FQ?24UE;5]P='(`4P!097)L
M7TE0<F]C7W!T<@``Z`%097)L7V-R;V%K7VYO8V]N=&5X=```30!097)L7TE$
M:7)?<'1R`&<`4&5R;%])8V]M<&-V7W!T<@``E`)097)L7VUG7W-E=`![`U!E
M<FQ?<W9?<V5T<'8`S@%097)L7V%V7W-H:69T`#@#4&5R;%]S=E\R<'9?;F]L
M96X`QP%097)L7V%V7V9E=&-H`#$"4&5R;%]G=E]F971C:'!V`+<!4&5R;%]4
M=&%I;G1E9%]P='(`00!097)L7T=O<%]M=71E>%]P='(``-,#<&5R;%]F<F5E
M`-(#<&5R;%]D97-T<G5C=`#6`W!E<FQ?<G5N``#5`W!E<FQ?<&%R<V4``/H"
M4&5R;%]S869E<WES;6%L;&]C``"$`%!E<FQ?265X:71?9FQA9W-?<'1R``#I
M`%!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`-$#<&5R;%]C;VYS=')U
M8W0``,P#<&5R;%]A;&QO8P``/P!097)L7T=D;U]U;F1U;7!?<'1R`,D#4&5R
M;%]W:6XS,E]I;FET`%!E<FPU-BYD;&P``"0!1V5T36]D=6QE1FEL94YA;65!
M``"T`$9R965,:6)R87)Y`"8!1V5T36]D=6QE2&%N9&QE00``50!$96QE=&5#
M<FET:6-A;%-E8W1I;VX`2T523D5,,S(N9&QL``#7`$=E=%5S97).86UE00``
M041605!),S(N9&QL``"R`G-P<FEN=&8`N`)S=')C;7```,<"<W1R=&]K``"^
M`G-T<FQE;@``Q0)S=')S='(``&T`7U]P7U]E;G9I<F]N``"8`FUE;6UO=F4`
MP0)S=')N8W!Y`,`"<W1R;F-M<`#(`%]E<G)N;P``@@%?;6MD:7(``(X!7W!C
M='EP90`5`5]I<V-T>7!E``!A`%]?;6)?8W5R7VUA>```EP)M96UC<'D``)D"
M;65M<V5T``"9`5]R;61I<@``WP!?9FEN9&-L;W-E``#B`%]F:6YD;F5X=`#=
M`5]U;FQI;FL`X`!?9FEN9&9I<G-T``"_`5]S=')D=7``Q0%?<W1R;FEC;7``
M35-60U)4+F1L;```TP!?97AI=`!(`%]88W!T1FEL=&5R`$D"97AI=```9`!?
M7W!?7U]I;FET96YV`%@`7U]G971M86EN87)G<P`/`5]I;FET=&5R;0"#`%]?
M<V5T=7-E<FUA=&AE<G(``)T`7V%D:G5S=%]F9&EV``!J`%]?<%]?8V]M;6]D
M90``;P!?7W!?7V9M;V1E``"!`%]?<V5T7V%P<%]T>7!E``#*`%]E>&-E<'1?
M:&%N9&QE<C,``+<`7V-O;G1R;VQF<```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(+!``!RP0`#_____.P```%P`
M``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`<&5R;'AS:2YC````)7,E
M<R5S```N````4$%27U!23T=.04U%`````%!!4E]414U0`````#$```!005)?
M0TQ%04X]``!#3$5!3@```%!!4E]'3$]"04Q?0TQ%04X`````4$%27T=,3T)!
M3%]414U0`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,
M3T)!3%]$14)51P````!005)?05)'5E\P``!005)?05)'0P````!005)?0T%#
M2$4```!005)?1$5"54<```!005)?0TQ%04X```!005)?4U!!5TY%1`!005)?
M24Y)5$E!3$E:140`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M````1%E,1%],24)205)97U!!5$@```!0051(`````$Q)0E)!4EE?4$%42```
M``!,24)0051(`$Q$7TQ)0E)!4EE?4$%42``E<R5S=&5M<"TE=2TE=25S````
M`"5S)7-T96UP+25U)7,````E,#)X`````"5S)7-C86-H92TE<R5S```E<R5S
M)7,E<P````!P87(M`````"5S7'1E;7``5VEN1&ER``!365-414T``%5315).
M04U%`````%5315(`````5$U0`%1%35``````5$5-4$1)4@!435!$25(``$,Z
M7%1%35``7"XN`%PN```E<P``)7-<)7,````E<UPJ+BH``"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("T@86)O<G1I;F<@=VET:"`E:2X*````,````'!E<FPN97AE`````!@```!!
M4D=6`````"TM```M90``26YT97)N86QS.CI005(Z.D)/3U0`````]+)``)]<
M``!P87(N<&P````````!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#``,````H``"`#@```$@``(`0
M````8```@````````````````````@`!````>```@`(```"0``"`````````
M```````````!`&4```"H``"````````````````````!``$```#```"`````
M```````````````!``````#8```````````````````````!``````#H````
M```````````````````!``````#X```````````````````````!```````(
M`0``F,,``&@%``````````````#)``"H"`````````````"HT0``(@``````
M````````(,$``'0"````````````````````````=`(T````5@!3`%\`5@!%
M`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X```$`````````````````
M`````#\````!````!``$``$```````````````````#4`0```0!3`'0`<@!I
M`&X`9P!&`&D`;`!E`$D`;@!F`&\```"P`0```0`P`#0`,``P`#``-`!B`#``
M```8`````0!#`&\`;0!M`&4`;@!T`',````@`````0!#`&\`;0!P`&$`;@!Y
M`$X`80!M`&4``````"@````!`$8`:0!L`&4`1`!E`',`8P!R`&D`<`!T`&D`
M;P!N```````@`````0!&`&D`;`!E`%8`90!R`',`:0!O`&X``````"`````!
M`$D`;@!T`&4`<@!N`&$`;`!.`&$`;0!E````)`````$`3`!E`&<`80!L`$,`
M;P!P`'D`<@!I`&<`:`!T````*`````$`3`!E`&<`80!L`%0`<@!A`&0`90!M
M`&$`<@!K`',``````"@````!`$\`<@!I`&<`:0!N`&$`;`!&`&D`;`!E`&X`
M80!M`&4````@`````0!0`'(`:0!V`&$`=`!E`$(`=0!I`&P`9````"`````!
M`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````)`````$`4`!R`&\`9`!U`&,`
M=`!6`&4`<@!S`&D`;P!N````(`````$`4P!P`&4`8P!I`&$`;`!"`'4`:0!L
M`&0```!$`````0!6`&$`<@!&`&D`;`!E`$D`;@!F`&\``````"0`!````%0`
M<@!A`&X`<P!L`&$`=`!I`&\`;@````````2P!``````H````$````"`````!
M``@````````!```````````````!`````0``!@8&``0$!``"`@(``````$)"
M0@"=G9T`;FYN`(&!@0"QL;$`____`'-S<P"?GY\`6%A8`+*RL@#]_?T`:VMK
M`/S\_`#7U]<`%A86`-K:V@"6EI8`CHZ.`$9&1@#+R\L`"PL+`*"@H`#^_OX`
MR<G)`,'!P0`#`P,`$1$1`).3DP"SL[,`[N[N`/3T]`#CX^,`Y>7E`**BH@"Z
MNKH`KZ^O``<'!P!Q<7$`M;6U`/7U]0")B8D`BHJ*`#0T-`#HZ.@`-34U`%I:
M6@"WM[<`V-C8`-#0T``='1T`#`P,`(^/CP"^OKX`;6UM``D)"0";FYL`+R\O
M`,W-S0#9V=D`&1D9`$U-30!$1$0`4%!0`#P\/`!D9&0`PL+"`#(R,@`("`@`
M#0T-``\/#P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````%!04%!04%!04%!04%!00$!`35`(P5!,4-!041%
M+@$!`0$!`0$%`3P7%P$!$P$!`0$!`0$!%0$!)A4!`0\!`0$!`0$!`1,!$0$%
M-0$F`0$!`0$!`0$B$A`Q#P4!(`$!`0$!`0$!$`H@(A45+B$N`0$!`0$?("$0
M(A`C(R4F)P$!`0$E$!`0$!`0$!`0%T4!`0%!$!`0$!`0$!`0$!`7`0$!#Q`0
M%1`0$!`0$!`0`0$!`1(0$!,?$!`0$!`0!P$!`0$@$!`0`0\0$!`0$0$!`0$!
M!R`0"@$!!1`0$#$!`0$!`0$!`0$!`0%!!0\!`0$!`0$!`0$!`0$!`0$!`0$!
M`0&``0``P`$``.`#``#P`P``\`,``/`#``#@`P``P`$``(`!``"``0``@`,`
M`(`#````!P````<``(X/``#_'P``*````"````!``````0`(````````!```
M`````````````0````$````````!`0$``@("``,#`P`$!`0`!04%``8&!@`'
M!P<`"`@(``D)"0`*"@H`"PL+``P,#``-#0T`#@X.``\/#P`0$!``$1$1`!(2
M$@`3$Q,`%!04`!45%0`6%A8`%Q<7`!@8&``9&1D`&AH:`!L;&P`<'!P`'1T=
M`!X>'@`?'Q\`("`@`"$A(0`B(B(`(R,C`"0D)``E)24`)B8F`"<G)P`H*"@`
M*2DI`"HJ*@`K*RL`+"PL`"TM+0`N+BX`+R\O`#`P,``Q,3$`,C(R`#,S,P`T
M-#0`-34U`#8V-@`W-S<`.#@X`#DY.0`Z.CH`.SL[`#P\/``]/3T`/CX^`#\_
M/P!`0$``04%!`$)"0@!#0T,`1$1$`$5%10!&1D8`1T='`$A(2`!)24D`2DI*
M`$M+2P!,3$P`34U-`$Y.3@!/3T\`4%!0`%%140!24E(`4U-3`%145`!5554`
M5E96`%=75P!86%@`65E9`%I:6@!;6UL`7%Q<`%U=70!>7EX`7U]?`&!@8`!A
M86$`8F)B`&-C8P!D9&0`965E`&9F9@!G9V<`:&AH`&EI:0!J:FH`:VMK`&QL
M;`!M;6T`;FYN`&]O;P!P<'``<7%Q`')R<@!S<W,`='1T`'5U=0!V=G8`=W=W
M`'AX>`!Y>7D`>GIZ`'M[>P!\?'P`?7U]`'Y^?@!_?W\`@("``(&!@0""@H(`
M@X.#`(2$A`"%A84`AH:&`(>'AP"(B(@`B8F)`(J*B@"+BXL`C(R,`(V-C0".
MCHX`CX^/`)"0D`"1D9$`DI*2`).3DP"4E)0`E965`):6E@"7EY<`F)B8`)F9
MF0":FIH`FYN;`)R<G`"=G9T`GIZ>`)^?GP"@H*``H:&A`**BH@"CHZ,`I*2D
M`*6EI0"FIJ8`IZ>G`*BHJ`"IJ:D`JJJJ`*NKJP"LK*P`K:VM`*ZNK@"OKZ\`
ML+"P`+&QL0"RLK(`L[.S`+2TM`"UM;4`MK:V`+>WMP"XN+@`N;FY`+JZN@"[
MN[L`O+R\`+V]O0"^OKX`O[^_`,#`P`#!P<$`PL+"`,/#PP#$Q,0`Q<7%`,;&
MQ@#'Q\<`R,C(`,G)R0#*RLH`R\O+`,S,S`#-S<T`SL[.`,_/SP#0T-``T='1
M`-+2T@#3T],`U-34`-75U0#6UM8`U]?7`-C8V`#9V=D`VMK:`-O;VP#<W-P`
MW=W=`-[>W@#?W]\`X.#@`.'AX0#BXN(`X^/C`.3DY`#EY>4`YN;F`.?GYP#H
MZ.@`Z>GI`.KJZ@#KZ^L`[.SL`.WM[0#N[NX`[^_O`/#P\`#Q\?$`\O+R`//S
M\P#T]/0`]?7U`/;V]@#W]_<`^/CX`/GY^0#Z^OH`^_O[`/S\_`#]_?T`_O[^
M`/___P`T-#0\/#P\/#P\/#P\/#P\/#P\/#P\/#PL#`0$!`0$!%RTU-34U-34
MU-34U-S4U-34U-34U-34U+0T400$!`0$9,SL]/3T_/3\]/3T_/3\]/ST_/S\
M]/3LQ#11400$!`1DQ.3L]/3T]/3T]/3T]/3T]/3T]/3T[.R\-%%1400$!&3$
MY.SL[.3L[.SDY.3D[.SD[.3L[.SLY+PT45%1400$9+SD[.RLC*S4Q)24G)2,
MC)24E)R<G.S<O#1145%1401DO-SD[.3$492L9.2D3#0L7,3,4;34Y-R\-%%1
M45%1462\W.3D[.3D481TY(QLI)QLC+QTK-3DW+PT!`0$!`0$9+S<Y.3LY.2\
M48S4U(RLS'3,W*11Q.3<O#0$!`0$!`1DO-SDY.3DY-R,?)RT?(2<;,SDO'3$
MY-RT-`0$!`0$!%R\W-SDY.3DU)RD7)2,S#R49,R\C%'<U+0T!`0$!`0$9+34
MW-S<Y-R,C*PLO+3,6L1DG&R4I-S4M#0$!`0$!`1<M-3<W.3<W'24U$RD](P\
MU'24=)Q,W,RT-`0$!`0$!&2TU-S<W.3<=%'T=(3LS&3D?&RDM&RDU+0T!`0$
M!`0$9+3,W-S,?(R$M/S,Q/STM/R\9,RLA%&\K#0$!`0$!`1<M,S4S(RDW-SL
M_/S\_/ST_.RT[*Q\E%&L-`0$!`0$!%RLS,QLG/3\_/S\_/S\_/S\_/S\Q)2,
M4:PT!`0$!`0$7*S$O'SD_/S\_/S\_/S\_/S\_/SLS*Q1K#0$!`0$!`1<K+1,
MQ/S\_.ST_/S\_/S\_/S\_/2\4<2L-`0$!`0$!%RLM$S4_/STM-S\_/S\_/S\
M_/S\S%',Q*0T!`0$!`0$7*S$I%'\_/RTG/3\_/S\_/S\_/244<S$I"P$!`0$
M!`1<I*11A.S\_,QDM.S\_/S\_/S\U&RLS+RD-`0$!`0$!%RD9'2\]/S\Q%&$
MG.3\_/S\_.2,4<S,Q*0T!`0$!`0$7*1LC.3T_/R<4<Q1E.S\_/S\O'3,S,2\
MG"P$!`0$!`1<I*QD7&2DI%&LS,1TE.3T_.11O,S,Q+R<-`0$!`0$!%RDM+R\
MC%%1Q,3,S*Q1?'R4;'R\S,3$O)PL!`0$!`0$7)R\Q,3$Q,3$Q,3$Q,1145%1
MO,3$Q,2TG#0$!`0$!`14G+3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,3$O+2<+`0$!`0$
M!%2<O,3$O+R\O+R\O+R\O+R\O+R\O+R\M)PL!`0$!`0$7)RTQ+RTM+2TM+2T
MM+2TM+2TM+2TM+2LG"P$!`0$!`14A)2<G)24E)24E)24E)24E)24E)24E)2$
M)`0$!`0$!$147%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%0T!`0$!`0$````/P``
M`!\````/````!P````,````!`````````#\````_````/P```#\````_````
M/P```#\````_````/P```#\````_````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\```$``@`0$````0`(
M`&@%```!`"`@```!``@`J`@```(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.0C$P`````&H@UDD!````1CI<4&5R;%]04$U<4$%2
<+5!A8VME<BTP+CDY,5QM>6QD<EQP87(N<&1B````
